@@ -1,5 +1,6 @@
 from fireREST import utils
 from fireREST.fmc import Connection, Resource
+from fireREST.fmc.object.network.override import Override
 
 
 class Network(Resource):
@@ -11,6 +12,10 @@ class Network(Resource):
     SUPPORTED_FILTERS = ['name_or_value', 'unused_only']
     SUPPORTED_PARAMS = ['override_target_id']
 
+    def __init__(self, conn: Connection):
+        super().__init__(conn)
+        self.override = Override(conn)
+
     @utils.support_params
     def get(self, uuid=None, name=None, name_or_value=None, unused_only=None, override_target_id=None, params=None):
         return super().get(uuid=uuid, name=name, params=params)
